@@ -8,7 +8,7 @@
 #
 use strict; use warnings;
 use strict; use warnings;
-use Test::More tests => 7;                      # last test to print
+use Test::More;
 
 my $objecta = MyApp->new_or_matching(identity => 'Mine');
 my $objectb = MyApp->new_or_matching(identity => 'Mine');
@@ -30,4 +30,5 @@ my $objectd = MyApp->new_or_matching(identity => 'Yours');
 
 is($objectd->number, 100, "Object D is good");
 
+
 1;
